#!/usr/bin/env bash
set -e

number_of_accounts=$(cat ./Accountlist.json | jq '.ChildAccountList | length')
TargetRegions=$(cat ./Accountlist.json| jq -r .TargetRegionList)
number_of_TargetRegions=$(cat ./Accountlist.json| jq '.TargetRegionList | length')
echo "Total number of accounts received in the input are ${number_of_accounts}"
echo "Child accounts assume role name is ${ChildAccountAssumeRoleName}"
echo "Target region for deploying the stack is ${TargetRegion}"

echo "******* Performing CloudFormation stack deployment to the obtained list of accounts `cat ./Accountlist.json| jq -r .ChildAccountList` *******"
errorcount=0
for (( jCount=0; jCount<${number_of_TargetRegions}; jCount++ ));
    do
        TargetRegion=$(cat ./Accountlist.json| jq -r .TargetRegionList[$jCount])
        echo "Running the template in the region - ${TargetRegion}"
        
        for (( iCount=0; iCount<${number_of_accounts}; iCount++ ));
            do
                TargetAccountId=$(cat ./Accountlist.json| jq -r .ChildAccountList[$iCount])

                echo "IAM Role that will be assumed from the account $TargetAccountId is arn:aws:iam::${TargetAccountId}:role/${ChildAccountAssumeRoleName}"

                aws configure --profile new-profile-${TargetAccountId} set role_arn arn:aws:iam::${TargetAccountId}:role/${ChildAccountAssumeRoleName}

                aws configure --profile new-profile-${TargetAccountId} set credential_source EcsContainer

                chmod +x ./deploy-cwlogs.sh

                echo "Deploying to the Target Account ${TargetAccountId} using the below credentials:"

                echo $(aws sts get-caller-identity --profile new-profile-${TargetAccountId})

                #Executing the script to perform CloudFormation package and deployment per account
                ./deploy-cwlogs.sh new-profile-${TargetAccountId} ${TargetRegion} || if [[ $? -ne 0 ]]; then errorcount=$(( $errorcount + 1 )); fi || continue
            done
    done

echo "error count is $errorcount"
if [[ $errorcount -gt 0 ]]; then
    echo "Looks like a complete deployment or a partial deployment failed. Please check the CodeBuild logs"
    exit 1
fi

echo "**** deployment complete for the list of accounts provided ****"
exec "$@"
